
`Visual Tracking eXchange protocol <http://prints.vicos.si/publications/311/>`_ is a simple protocol that enables easier evaluation of computer vision tracking algorithms. The basic idea is that a tracker communicates with the evaluation software using a set of text commands over the (standard) input/output streams or TCP sockets. 

This package contains a Python wrapper to C library (using CTypes) available in the `support/python` directory. More information and source code available at `Github <https://github.com/votchallenge/trax/>`_.